@@ -189,6 +189,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Pycsou",
     "Framework :: Pydantic",
     "Framework :: Pydantic :: 1",
+    "Framework :: Pydantic :: 2",
     "Framework :: Pylons",
     "Framework :: Pyramid",
     "Framework :: Pytest",
@@ -592,6 +593,9 @@ sorted_classifiers: List[str] = [
     "Topic :: Education",
     "Topic :: Education :: Computer Aided Instruction (CAI)",
     "Topic :: Education :: Testing",
+    "Topic :: File Formats",
+    "Topic :: File Formats :: JSON",
+    "Topic :: File Formats :: JSON :: JSON Schema",
     "Topic :: Games/Entertainment",
     "Topic :: Games/Entertainment :: Arcade",
     "Topic :: Games/Entertainment :: Board Games",
